#
# spec file for package translate-toolkit
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           translate-toolkit
Version:        2.4.0
Release:        lp151.2.3.6
Summary:        Tools and API to assist with translation and software localization
License:        GPL-2.0-or-later
Group:          Development/Tools/Other
URL:            http://toolkit.translatehouse.org/
Source:         https://github.com/translate/translate/releases/download/%{version}/%{name}-%{version}.tar.gz
# Repacked https://github.com/translate/sphinx-themes ; no commits since 2013
# Often not included in the release tag so just ship it
Source1:        sphinx-themes.tar.xz
Patch0:         sphinx-intersphinx.patch
Patch2:         xliff-xsd-no-network.patch
BuildRequires:  fdupes
BuildRequires:  gettext-runtime
BuildRequires:  git-core
BuildRequires:  iso-codes
BuildRequires:  python3-Babel
BuildRequires:  python3-Levenshtein
BuildRequires:  python3-Sphinx
BuildRequires:  python3-beautifulsoup4
BuildRequires:  python3-cheroot
BuildRequires:  python3-iniparse
BuildRequires:  python3-l20n
BuildRequires:  python3-lxml >= 3.5.0
BuildRequires:  python3-phply
BuildRequires:  python3-pycountry >= 18.12.8
BuildRequires:  python3-pyenchant
BuildRequires:  python3-pytest
BuildRequires:  python3-ruamel.yaml
BuildRequires:  python3-six >= 1.11.0
BuildRequires:  python3-vobject
BuildRequires:  python3-xml
BuildRequires:  subversion
Requires:       gettext-runtime
Requires:       python3-lxml
Requires:       python3-pycountry >= 18.12.8
Requires:       python3-pyenchant
Requires:       python3-setuptools
Requires:       python3-six >= 1.11.0
# The following are for the full experience of translate-toolkit
Recommends:     gaupol
Recommends:     iso-codes
Recommends:     python3-Levenshtein
Recommends:     python3-aeidon
Recommends:     python3-chardet
Recommends:     python3-cheroot
Recommends:     python3-iniparse
Recommends:     python3-l20n
Recommends:     python3-phply
Recommends:     python3-pycountry
Recommends:     python3-ruamel.yaml
Recommends:     python3-vobject
Provides:       python3-translate-toolkit = %{version}
BuildArch:      noarch

%description
The Translate Toolkit is a set of software and documentation designed to help
make the lives of localizers both more productive and less frustrating.

The software includes programs to convert localization formats to the common
PO, and emerging XLIFF format.  There are also programs to check and manage PO
and XLIFF files.  Online documentation includes guides on using the tools,
running a localization project and how to localize various projects from
OpenOffice.org to Mozilla.

At its core the software contains a set of classes for handling various
localization storage formats: DTD, properties, OpenOffice.org GSI/SDF,
CSV, MO, Qt .ts, TMX, TBX, WordFast txt, Gettext .mo, Windows RC, and
of course PO and XLIFF.  It also provides scripts to convert between
these formats.

Also part of the Toolkit are Python programs to create word counts, merge
translations and perform various checks on translation files.

%package devel-doc
Summary:        Tools and API to assist with translation and software localization
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}
BuildArch:      noarch

%description devel-doc
The %{name}-devel-doc package contains Translate Toolkit API documentation for developers wishing to build new tools for the
toolkit or to use the libraries in other localization tools.

%prep
%setup -q
%autopatch -p1

pushd docs/_themes
tar -xJf %{SOURCE1} --strip 1
popd

sed -i 296"s|'share'|'translate/share'|" setup.py

#Fix for shebang errors:
for lib in translate/{*.py,*/*.py,*/*/*.py}; do
 sed -i '\|%{_bindir}/env |d' $lib
done

%build
python3 setup.py build
pushd docs
# Can't use parallel build here!
make -j1 html man
#no hidden files
find _build -name '.?*' -delete
popd

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# create manpages
mkdir -p %{buildroot}/%{_mandir}/man1
for program in %{buildroot}/%{_bindir}/*; do
    case $(basename $program) in
      pocompendium|poen|pomigrate2|popuretext|poreencode|posplit|pocount|poglossary|lookupclient.py|tmserver|build_tmdb)
        ;;
      *)
        LC_ALL=C PYTHONPATH=. $program --manpage \
          >  %{buildroot}/%{_mandir}/man1/$(basename $program).1 \
          || rm -f %{buildroot}/%{_mandir}/man1/$(basename $program).1
        ;;
    esac
done
install -m 644 docs/_build/man/* %{buildroot}/%{_mandir}/man1/

# move documentation files to datadir
install -d -m 755 %{buildroot}%{_defaultdocdir}/%{name}
mv %{buildroot}%{python3_sitelib}/translate/docs/_build/html %{buildroot}%{_defaultdocdir}/%{name}
rm -rf %{buildroot}%{python3_sitelib}/translate/docs
rm -rf %{buildroot}/home/abuild/.local/lib/python%{python3_version}/site-packages/

# create symlinks for man pages
%fdupes -s %{buildroot}/%{_mandir}
# create hardlinks for the rest
%fdupes %{buildroot}

%check
export PATH=$PATH:%{buildroot}%{_bindir}
PYTHONPATH=%{buildroot}%{python3_sitelib} python3 -m pytest -v

%files
%{_defaultdocdir}/%{name}/html/
%exclude %{_defaultdocdir}/%{name}/html/api
%exclude %{_defaultdocdir}/%{name}/html/_sources
%license COPYING
%doc README.rst
%{_bindir}/*
%{_mandir}/man1/*
%{python3_sitelib}/translate
%{python3_sitelib}/translate_toolkit-%{version}-*.egg-info

%files devel-doc
%doc %{_defaultdocdir}/%{name}/html/api
%doc %{_defaultdocdir}/%{name}/html/_sources

%changelog
* Thu Jul 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.0:
  * Added new Flat XML format and converters.
  * Fixes for multiple formats.
- Remove merged patches:
  * pycountry.patch
  * test-pytest310.patch
* Thu Apr  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not depend on strace, it is not really needed
* Fri Mar 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with current pycountry:
  * pycountry.patch
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop not needed lxml-doc dependency
* Mon Jan 28 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid mixing historic and modern option syntax for tar.
- Replace find -exec rm by just find -delete.
* Mon Jan 28 2019 Luiz Fernando Ranghetti <elchevive68@gmail.com>
- Correct the Source URL
* Thu Jan 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Make sure the documentation is generated properly
- Enable testsuite
- Add patches from debian for tests to pass:
  * sphinx-intersphinx.patch
  * test-pytest310.patch
  * xliff-xsd-no-network.patch
* Tue Dec 18 2018 sbrabec@suse.com
- Update to 2.3.1:
  * But fixes.
  * INI: Enabled support for Python3 provided.
  * Use backports.csv module on Python 2 to align the behavior
    with Python 3 and drop many hacks.
  * Removed deprecated getoutput, add new depreceations.
  * Code cleanup; many converterters refactored.
* Wed Mar 21 2018 elchevive@opensuse.org
- update to 2.3.0
  * Full rewrite of the PHP format greatly extending the support.
  * Added YAML format converters.
  * Major refactor of converters code.
- drop patch translate-toolkit-2.0.0-python-six.diff not needed
  on Leap 15.0
* Tue Dec 26 2017 astieger@suse.com
- update to 2.2.5:
  * Fixed bug when adding new units to XLIFF store.
  * Added support for i18next JSON dialect.
  * Improved WebExtension JSON dialect support.
* Tue Nov 14 2017 jmatejek@suse.com
- drop unneeded requirement for python-utidy
- drop unneeded requirements for diff_match_patch
- switch to python3
* Mon Aug 28 2017 elchevive@opensuse.org
- Update do 2.2.4
  * Added support for nested and WebExtension JSON dialects.
  * po2txt no longer converts non-translatable strings.
  * Improvement for puncspace check.
  * Support for .xliff extension.
* Mon Jun 26 2017 elchevive@opensuse.org
- Update do 2.2.3
  * Added MinimalChecker and ReducedChecker checkers.
  * Fixed resolving of country names translations.
  * Refactored functions for resolving language/country names translation to be memory efficient.
  * Improvements for ts and subtitles formats.
  * Added –preserveplaceholders argument to podebug.
  * Fixed Montenegrin language name.
* Fri Jun 16 2017 elchevive@opensuse.org
- add python-pycountry as Requires
- Update do 2.2.0
  * Avoid resolving external entities while parsing XML.
  * Improvements for Android, ts and resx formats.
  * Added support for PHP nested arrays.
  * Added Kabyle language
* Mon Mar 20 2017 elchevive@opensuse.org
- Update do 2.1.0
  * Fixed RomanianChecker checks.
  * Added an iOS checker style.
  * Changed plural equations for Slovenian, Persian, Kazakh and Kyrgyz.
  * Several fixes in formats and tools.
* Mon Mar  6 2017 lnussel@suse.de
- lower python-six requirement to 1.9 again to make translate-toolkit work on
  Leap. There is no real requirement on 1.10:
  https://github.com/translate/translate/pull/3488
  * translate-toolkit-2.0.0-python-six.diff
* Sun Feb 26 2017 dimstar@opensuse.org
- Explicitly package %%{_defaultdocdir}/%%{name}/html: fix build with
  RPM 4.13.
* Mon Jan 30 2017 elchevive@opensuse.org
- Update do 2.0.0
  * po2txt works correctly again when --threshold option is passed
  (https://github.com/translate/translate/issues/3499) boo#999286
* Tue Jan 24 2017 elchevive@opensuse.org
- Add missing Requires: python-setuptools
* Mon Jan 16 2017 elchevive@opensuse.org
- Update to 1.99.9 (2.0.0 RC2)
  * Minor fixes
* Thu Sep  1 2016 elchevive@opensuse.org
- Update to 1.99.5 (2.0.0 Beta 5)
  * Minor fixes
- require lxml 3.5.0 or newer
* Wed Jul 27 2016 buschmann23@opensuse.org
- Update to 1.99.3 (2.0.0 Beta 3)
  * Python 3 compatibility thanks to Claude Paroz
  * Dropped support for Python 2.6
  * Changes in storage API to expose a more standardized API
- require python 2.7 or newer
* Thu Apr 28 2016 michal@cihar.com
- Update to 1.14.0-rc1
* Tue Nov 10 2015 mcihar@suse.cz
- Fix documentation build (breaks in parallel build)
* Tue Nov 10 2015 mcihar@suse.cz
- python-six is required for build as well (for API docs)
* Tue Nov 10 2015 mcihar@suse.cz
- Remove Sphinx build cache before building docs
* Wed Jul 29 2015 dimstar@opensuse.org
- Require python-six: translate/misc/quote.py depends on it.
* Wed Jul 15 2015 mcihar@suse.cz
- use spec-cleaner to sort dependencies
* Wed Jul 15 2015 mcihar@suse.cz
- make dependency on several optional features only recommended: vobject,
  Levenshtein, aeidon, iniparse
- remove not needed xapian build dependency
- remove not used simplejson from build/runtime dependencies
* Fri May 15 2015 elchevive@opensuse.org
- updated to version 1.13.0
- updated Source URL and run spec-cleaner
  Major changes
  New converters for IDML format
  Support for new .Net Resource (.resx) format
  Extensive cleanup on ODF converters
  New quality checks
    Some bugfixes and improvements
* Thu Nov  6 2014 mcihar@suse.cz
- remove not needed gaupol build dependency
* Tue Aug 12 2014 elchevive@opensuse.org
- updated to version 1.12.0
  Major changes
  Properties and DTD formats fix a number of issues
  Massive code cleanup looking forward Python 3 compatibility
  Important changes in development process to ease testing
* Thu Jan 30 2014 elchevive@opensuse.org
- updated to version 1.11.0
  Major changes:
  The PO format now matches Gettext more closely
  PHP format adds a number of new features
  Support for Python 2.5 has been dropped
* Sun Jul 14 2013 elchevive@opensuse.org
- add 2 missing BuildRequires (python-Levenshtein and change
  python-aeidon with gaupol)
* Fri Jun 28 2013 elchevive@opensuse.org
- Add python-{Levenshtein,aeidon} as Requires and remove again
  diff_match_patch as its not allowed on Factory (license issue)
* Tue Mar 26 2013 fa0sck@gmail.com
- New upstream version (1.10.0)
  * devel package renamed as devel-doc.
* Sat Jan 12 2013 dmitry.rojkov@gmail.com
- initial repackaging
* Tue Jun  5 2012 i@marguerite.su
- fix sles builds.
  * version tag for buildarch: noarch.
* Thu May 10 2012 elchevive@opensuse.org
- Remove psyco references as it is a dead project
* Thu Apr 19 2012 elchevive@opensuse.org
- Add Provides: python-translate-toolkit for compatibility with old packages
* Mon Mar 26 2012 elchevive@opensuse.org
- Cosmetic change in 'for' used to remove shebangs
* Tue Mar 20 2012 elchevive@opensuse.org
- Add proper specfile header as requested in sr#109322
* Wed Mar 14 2012 elchevive@opensuse.org
- Fix for bnc#750652 (remove Apache-2.0 file as the programa has a fallbak)
* Sun Feb 26 2012 elchevive@opensuse.org
- Add ifelse to python-pyenchant (new name for > 12.1)
* Wed Feb 22 2012 elchevive@opensuse.org
- Fix the non-executable-script warning
* Wed Apr 13 2011 elchevive@opensuse.org
- Updated to version 1.9.0
  Highlighted improvements
  - Faster terminology matching
  - Several small optimisations to performance and memory use
  - More advanced state support (visible in pocount and Virtaal 0.7)
  - Improved language detection models (+South African languages)
  - Improve handling of printf variable reordering [Jacques Beaurain]
  - Review of the wording of the messages of pofilter checks
  - Better sentence segmentation for some non-Latin languages
  - More supported formats for podebug
  - Extra options for pomerge, pogrep and po2oo/xliff2oo. The new pogrep options made this possible for GNOME: http://translate.org.za/blogs/friedel/en/content/better-lies-about-gnome-localisation
  Most relevant for Pootle:
  - Support for Xapian 1.2 (bug 1766) [Rimas Kudelis]
  - Work around some changes introduced in Django 1.2.5/1.3
  Format support:
  - Always use UNIX line endings for PO (even on Windows)
  - XLIFF and .ts files now shows "fuzzy" only the target present
  - Improved support for .ts comment as context (bug 1739)
  - Support for Java properties in UTF-8 encoding
  - More natural string ordering in json converter
  - Improved handling of trailing spaces in Mozilla DTD files
  - Removed unused support for _old_ KDE plurals in pocount
  ...and several small bugfixes
* Mon Dec 27 2010 elchevive@opensuse.org
- Removed 11.1 references and python- prefix
* Fri Nov 19 2010 elchevive@opensuse.org
- Updated to version 1.8.1
* Tue Aug 17 2010 elchevive@opensuse.org
- Updated to version 1.8.0
- Set Gaupol as Suggestion
* Wed May 12 2010 elchevive@opensuse.org
- Updated to version 1.7.0
* Fri Mar  5 2010 elchevive@opensuse.org
- Updated to version 1.6.0
- Added python-enchant as Requires
* Tue Feb 23 2010 elchevive@opensuse.org
- Rename -doc to -devel (as it is devel's docs)
- Added more requires (for ical2po, sub2po work)
- Remove duplicated docs in -devel
* Mon Feb 22 2010 elchevive@opensuse.org
- Package split (-doc) and manpages created (using Fedora's .spec)
* Tue Feb 16 2010 elchevive@opensuse.org
- Package updated to version 1.5.3
* Mon Jan 25 2010 elchevive@opensuse.org
- Added gettext-runtime as requirement
* Wed Jan 20 2010 elchevive@opensuse.org
- Added python-lxml as requirement
* Thu Jan 14 2010 elchevive@opensuse.org
- Initial release 1.5.2 - spec/rpmlint copyed from thomas-schaite repository
